@@ -1,6 +1,6 @@
 #' Fast Imputation of Missing Values by Chained Random Forests
 #' 
-#' Uses the "ranger" package (Wright & Ziegler) to do fast missing value imputation by 
+#' Uses the {ranger} package (Wright & Ziegler) to do fast missing value imputation by 
 #' chained random forests, see Stekhoven & Buehlmann and Van Buuren & Groothuis-Oudshoorn.
 #' Between the iterative model fitting, it offers the option of predictive mean matching. 
 #' This firstly avoids imputation with values not present in the original data 
@@ -21,14 +21,11 @@
 #' single-argument function of the number of available covariables, 
 #' e.g. \code{mtry = function(m) max(1, m %/% 3)}.
 #' 
-#' @importFrom stats var reformulate terms.formula predict setNames
-#' @importFrom ranger ranger
-#' @importFrom utils setTxtProgressBar txtProgressBar
 #' @param data A \code{data.frame} or \code{tibble} with missing values to impute.
 #' @param formula A two-sided formula specifying variables to be imputed 
 #' (left hand side) and variables used to impute (right hand side). 
-#' Defaults to \code{. ~ .}, i.e. use all variables to impute all variables. 
-#' If e.g. all variables (with missings) should be imputed by all variables 
+#' Defaults to \code{. ~ .}, i.e., use all variables to impute all variables. 
+#' For instance, if all variables (with missings) should be imputed by all variables 
 #' except variable "ID", use \code{. ~ . - ID}. Note that a "." is evaluated 
 #' separately for each side of the formula. Further note that variables with missings 
 #' must appear in the left hand side if they should be used on the right hand side.
@@ -47,10 +44,10 @@
 #' is added to the output as attribute "oob". This does not work in the special case 
 #' when the variables are imputed univariately.
 #' @param case.weights Vector with non-negative case weights.
-#' @param ... Arguments passed to \code{ranger()}. If the data set is large, 
+#' @param ... Arguments passed to \code{ranger::ranger()}. If the data set is large, 
 #' better use less trees (e.g. \code{num.trees = 20}) and/or a low value of 
 #' \code{sample.fraction}. 
-#' The following arguments are e.g. incompatible: 
+#' The following arguments are incompatible, amongst others: 
 #' \code{write.forest}, \code{probability}, \code{split.select.weights}, 
 #' \code{dependent.variable.name}, and \code{classification}. 
 #'
@@ -77,8 +74,13 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   }
   
   # 1) INITIAL CHECKS
-  bad_args <- c("write.forest", "probability", "split.select.weights",  
-                "dependent.variable.name", "classification")
+  bad_args <- c(
+    "write.forest", 
+    "probability", 
+    "split.select.weights",  
+    "dependent.variable.name", 
+    "classification"
+  )
   stopifnot(
     "'data' should be a data.frame!" = is.data.frame(data), 
     "'data' should have at least one row and column!" = dim(data) >= 1L, 
@@ -106,11 +108,11 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   # 2) SELECT AND CONVERT VARIABLES TO IMPUTE
   
   # Extract lhs and rhs from formula
-  relevantVars <- lapply(formula[2:3], function(z) attr(terms.formula(
-    reformulate(z), data = data[1, ]), "term.labels"))
+  relevantVars <- lapply(formula[2:3], function(z) attr(stats::terms.formula(
+    stats::reformulate(z), data = data[1L, ]), "term.labels"))
   
   # Pick variables from lhs with some but not all missings
-  toImpute <- relevantVars[[1]][vapply(data[, relevantVars[[1]], drop = FALSE], 
+  toImpute <- relevantVars[[1L]][vapply(data[, relevantVars[[1L]], drop = FALSE], 
                 FUN.VALUE = TRUE, function(z) anyNA(z) && !all(is.na(z)))]
   
   # Try to convert special variables to numeric/factor
@@ -141,8 +143,8 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   
   # Variables on the rhs should either appear in "visitSeq" 
   # or do not contain any missings
-  imputeBy <- relevantVars[[2]][relevantVars[[2]] %in% visitSeq | 
-     !vapply(data[, relevantVars[[2]], drop = FALSE], anyNA, TRUE)]
+  imputeBy <- relevantVars[[2L]][relevantVars[[2L]] %in% visitSeq | 
+     !vapply(data[, relevantVars[[2L]], drop = FALSE], anyNA, TRUE)]
   completed <- setdiff(imputeBy, visitSeq)
   
   if (verbose) {
@@ -157,7 +159,7 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   j <- 1L
   crit <- TRUE
   verboseDigits <- 4L
-  predError <- setNames(rep(1, length(visitSeq)), visitSeq)
+  predError <- stats::setNames(rep(1, length(visitSeq)), visitSeq)
   
   if (verbose >= 2) {
     cat("\n", abbreviate(visitSeq, minlength = verboseDigits + 2L), sep = "\t")
@@ -167,11 +169,11 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   while (crit && j <= maxiter) {
     if (verbose) {
       if (verbose == 1) {
-        i <- 1
+        i <- 1L
         cat("\n")
         cat(paste("iter", j))
         cat("\n")
-        pb <- txtProgressBar(0, length(visitSeq), style = 3)
+        pb <- utils::txtProgressBar(0, length(visitSeq), style = 3)
       } else if (verbose >= 2) {
         cat("\niter ", j, ":\t", sep = "")
       }
@@ -186,16 +188,18 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
       if (length(completed) == 0L) {
         data[[v]] <- imputeUnivariate(data[[v]])
       } else {
-        fit <- ranger(formula = reformulate(completed, response = v), 
-                      data = data[!v.na, union(v, completed), drop = FALSE],
-                      case.weights = case.weights[!v.na], ...)
-        pred <- predict(fit, data[v.na, completed, drop = FALSE])$predictions
-        data[v.na, v] <- if (pmm.k) pmm(xtrain = fit$predictions, 
-                                        xtest = pred, 
-                                        ytrain = data[[v]][!v.na], 
-                                        k = pmm.k) else pred
+        fit <- ranger::ranger(
+          formula = stats::reformulate(completed, response = v),
+          data = data[!v.na, union(v, completed), drop = FALSE],
+          case.weights = case.weights[!v.na], 
+          ...
+        )
+        pred <- stats::predict(fit, data[v.na, completed, drop = FALSE])$predictions
+        data[v.na, v] <- if (pmm.k) pmm(
+          xtrain = fit$predictions, xtest = pred, ytrain = data[[v]][!v.na], k = pmm.k
+        ) else pred
         predError[[v]] <- fit$prediction.error / (
-          if (fit$treetype == "Regression") var(data[[v]][!v.na]) else 1
+          if (fit$treetype == "Regression") stats::var(data[[v]][!v.na]) else 1
         )
         
         if (is.nan(predError[[v]])) {
@@ -209,8 +213,8 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
       
       if (verbose) {
         if (verbose == 1) {
-          setTxtProgressBar(pb, i)
-          i <- i + 1
+          utils::setTxtProgressBar(pb, i)
+          i <- i + 1L
         } else if (verbose >= 2) {
           cat(format(round(predError[[v]], verboseDigits), 
                      nsmall = verboseDigits), "\t")  
@@ -239,15 +243,14 @@ missRanger <- function(data, formula = . ~ ., pmm.k = 0L, maxiter = 10L,
   revert(converted, X = dataLast)
 }
 
-#' A version of \code{typeof} internally used by \code{missRanger}.
+#' A version of \code{typeof()} internally used by \code{missRanger()}.
 #'
-#' @description Returns either "numeric" (double or integer), "factor", "character", "logical", "special" (mode numeric, but neither double nor integer) or "" (otherwise).
-#' \code{missRanger} requires this information to deal with response types not natively supported by \code{ranger}.
-#' 
-#' @author Michael Mayer
+#' Returns either "numeric" (double or integer), "factor", "character", "logical", 
+#' "special" (mode numeric, but neither double nor integer) or "" (otherwise).
+#' \code{missRanger} requires this information to deal with response types not natively 
+#' supported by \code{ranger::ranger()}.
 #' 
 #' @param object Any object.
-#'
 #' @return A string.
 typeof2 <- function(object) {
   if (is.numeric(object)) "numeric" else
@@ -259,14 +262,16 @@ typeof2 <- function(object) {
 
 #' Conversion of non-factor/non-numeric variables.
 #'
-#' @description Converts non-factor/non-numeric variables in a data frame to factor/numeric. Stores information to revert back.
-#' 
-#' @author Michael Mayer
+#' Converts non-factor/non-numeric variables in a data frame to factor/numeric. 
+#' Stores information to revert back.
 #' 
 #' @param X A data frame.
-#' @param check If \code{TRUE}, the function checks if the converted columns can be reverted without changes.
-#'
-#' @return A list with the following elements: \code{X} is the converted data frame, \code{vars}, \code{types}, \code{classes} are the names, types and classes of the converted variables. Finally, \code{bad} names variables in \code{X} that should have been converted but could not. 
+#' @param check If \code{TRUE}, the function checks if the converted columns can be 
+#' reverted without changes.
+#' @return A list with the following elements: \code{X} is the converted data frame, 
+#' \code{vars}, \code{types}, \code{classes} are the names, types and classes of the 
+#' converted variables. Finally, \code{bad} names variables in \code{X} that should 
+#' have been converted but could not. 
 convert <- function(X, check = FALSE) {
   stopifnot(is.data.frame(X))
   
@@ -289,14 +294,11 @@ convert <- function(X, check = FALSE) {
 }
 
 #' Revert conversion.
-#'
-#' @description Reverts conversions done by \code{convert}.
 #' 
-#' @author Michael Mayer
-#' 
-#' @param con A list returned by \code{convert}.
-#' @param X A data frame with some columns to be converted back according to the information stored in \code{converted}.
-#'
+#' Reverts conversions done by \code{convert()}.
+#' @param con A list returned by \code{convert()}.
+#' @param X A data frame with some columns to be converted back according to the 
+#' information stored in \code{converted}.
 #' @return A data frame.
 revert <- function(con, X = con$X) {
   stopifnot(c("vars", "types", "classes") %in% names(con), is.data.frame(X))
@@ -306,8 +308,13 @@ revert <- function(con, X = con$X) {
   }
   
   f <- function(v, ty, cl) {
-    switch(ty, logical = as.logical(v), character = as.character(v),
-           special = {class(v) <- cl; v}, v)
+    switch(
+      ty, 
+      logical = as.logical(v), 
+      character = as.character(v),
+      special = {class(v) <- cl; v}, 
+      v
+    )
   }
   X[, con$vars] <- Map(f, X[, con$vars, drop = FALSE], con$types, con$classes)
   X
